<?PHP // $Id$ 
      // error.php - created with Moodle 1.4.3 + (2004083132)


$string['coursegroupunknown'] = ',   $a  ';
$string['erroronline'] = '   $a';
$string['fieldrequired'] = '\"$a\"  ';
$string['filenotfound'] = ',       ';
$string['groupalready'] = '     $a';
$string['groupunknown'] = ' $a     ';
$string['invalidfieldname'] = '\"$a\"   ';
$string['missingfield'] = '  \"$a\"';
$string['modulerequirementsnotmet'] = ' \"$a->modulename\" ($a->moduleversion)    .       (   $a->currentmoodle,     $a->requiremoodle).';
$string['notavailable'] = '   .';
$string['restricteduser'] = ',     \"$a\"     .';
$string['unknowncourse'] = '   ';
$string['usernotaddederror'] = ' \"$a\"   -  ';
$string['usernotaddedregistered'] = ' \"$a\"   -  ';
$string['usernotavailable'] = '      .';

?>
